pub enum NetlinkError {
Io(Error),
NotFound(String),
Netlink(String),
}Expand description
Errors returned by the netlink helpers in this module.
Variants
Io(Error)
Failed to open or access a file (typically /proc/<pid>/ns/net).
NotFound(String)
The requested link was not found in the current network namespace.
Netlink(String)
A netlink operation failed.